import AbstractProductService from '../services/abstractproduct.js';
import fs from 'fs';
import path from 'path';
import customError from '../response/customError.js';
import responseCodes from '../response/responseCodes.js';
import translate from '../utils/translate.js';

const TAG = "/controllers/abstractproduct.js";

class AbstractProductController {
    async create(req, res) {
        const { groupId, localId, barcode, name, net_weight, image_filename, category, unit } = req.body;

        const tempPath = req.file.path;
        const targetPath = path.join(path.resolve(path.dirname('')), `/uploads/${image_filename}.png`);

        if (path.extname(req.file.originalname).toLowerCase() !== ".png") {
            fs.rmSync(tempPath);
            throw new customError(`create abstract product only png allowed`, responseCodes.responses.general.png_only);
        }

        fs.copyFileSync(tempPath, targetPath);
        fs.rmSync(tempPath);

        await AbstractProductService.create(groupId, localId, barcode, name, net_weight, image_filename, category, unit);
        return res.status(200).send(translate(req.headers["accept-language"], responseCodes.responses.general.ok));
    }

    async update(req, res) {
        let { groupId, localId, barcode, name, net_weight, image_filename, category, unit } = req.body;

        const tempPath = req.file.path;
        const targetPath = path.join(path.resolve(path.dirname('')) + `/uploads/${image_filename}.png`);


        if (barcode) await AbstractProductService.updateBarcode(groupId, localId, barcode);

        if (name) await AbstractProductService.updateName(groupId, localId, name);

        if (net_weight) await AbstractProductService.updateNetWeight(groupId, localId, net_weight);

        if (image_filename && tempPath) {
            fs.copyFileSync(tempPath, targetPath);
            fs.rmSync(tempPath);
            await AbstractProductService.updateImageFilename(groupId, localId, image_filename);
        } else if (image_filename && !tempPath) {
            throw new customError(`Abstract product update image hash without file`, responseCodes.responses.abstractproducts.hash_without_file);
        } else if (!image_file && tempPath) {
            fs.rmSync(tempPath);
            throw new customError(`Abstract product update file without image hash`, responseCodes.responses.abstractproducts.file_without_hash);
        }

        if (category) await AbstractProductService.updateCategory(groupId, localId, category);

        if (unit) await AbstractProductService.updateUnit(groupId, localId, unit);

        return res.status(200).send(translate(req.headers["accept-language"], responseCodes.responses.general.ok));
    }
};

export default new AbstractProductController();
